# attention_grabber

Extension for JupyterLab.

Flashes your screen and plays a noise when cells are finished, until you interact on the notebook again.

Toggle this on by right-clicking and pressing "Toggle Attention Grabber". Otherwise, this does nothing.
